pluggy: Plugin and hook calling mechanisms for python
=====================================================

Description
-----------

Plugin and hook calling mechanisms for python

License
-------

MIT license

Upstream Contact
----------------

https://pypi.org/project/pluggy/

